==> zeebe-client-java-8.6.0-sources.jar: io/camunda/zeebe/client/impl/response/CorrelateMessageResponseImpl.java <==
/*
 * Copyright © 2017 camunda services GmbH (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.camunda.zeebe.client.impl.response;

import io.camunda.zeebe.client.api.JsonMapper;
import io.camunda.zeebe.client.api.response.CorrelateMessageResponse;
import io.camunda.zeebe.client.protocol.rest.MessageCorrelationResponse;

public final class CorrelateMessageResponseImpl implements CorrelateMessageResponse {

  private final JsonMapper jsonMapper;
  private long key;
  private String tenantId;
  private long processInstanceKey;

  public CorrelateMessageResponseImpl(final JsonMapper jsonMapper) {
    this.jsonMapper = jsonMapper;
  }

  @Override
  public Long getMessageKey() {
    return key;
  }

  @Override
  public String getTenantId() {
    return tenantId;
  }

  @Override
  public Long getProcessInstanceKey() {
    return processInstanceKey;
  }

  public CorrelateMessageResponseImpl setResponse(final MessageCorrelationResponse response) {
    key = response.getMessageKey();
    tenantId = response.getTenantId();
    processInstanceKey = response.getProcessInstanceKey();
    return this;
  }
}

==> zeebe-client-java-8.8.8-sources.jar: io/camunda/zeebe/client/impl/response/CorrelateMessageResponseImpl.java <==
/*
 * Copyright © 2017 camunda services GmbH (info@camunda.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.camunda.zeebe.client.impl.response;

import io.camunda.zeebe.client.api.JsonMapper;
import io.camunda.zeebe.client.api.response.CorrelateMessageResponse;
import io.camunda.zeebe.client.impl.util.ParseUtil;
import io.camunda.zeebe.client.protocol.rest.MessageCorrelationResult;

public final class CorrelateMessageResponseImpl implements CorrelateMessageResponse {

  private final JsonMapper jsonMapper;
  private long key;
  private String tenantId;
  private long processInstanceKey;

  public CorrelateMessageResponseImpl(final JsonMapper jsonMapper) {
    this.jsonMapper = jsonMapper;
  }

  @Override
  public Long getMessageKey() {
    return key;
  }

  @Override
  public String getTenantId() {
    return tenantId;
  }

  @Override
  public Long getProcessInstanceKey() {
    return processInstanceKey;
  }

  public CorrelateMessageResponseImpl setResponse(final MessageCorrelationResult response) {
    key = ParseUtil.parseLongOrEmpty(response.getMessageKey());
    tenantId = response.getTenantId();
    processInstanceKey = ParseUtil.parseLongOrEmpty(response.getProcessInstanceKey());
    return this;
  }
}
